==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/BRANCHCONDITIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BRANCHCONDITIONDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BRANCHCONDITIONDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHPATTERN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BRANCHGOTO"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLEARPREVVALUES" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BRANCHCONDITIONDETAILS_Type", propOrder = {
    "branchcondition",
    "branchpattern",
    "branchgoto",
    "clearprevvalues"
})
public class BRANCHCONDITIONDETAILS_Type {

    @XmlElement(name = "BRANCHCONDITION", required = true)
    protected String branchcondition;
    @XmlElement(name = "BRANCHPATTERN", required = true)
    protected String branchpattern;
    @XmlElement(name = "BRANCHGOTO")
    protected long branchgoto;
    @XmlElement(name = "CLEARPREVVALUES")
    protected String clearprevvalues;

    /**
     * Gets the value of the branchcondition property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHCONDITION() {
        return branchcondition;
    }

    /**
     * Sets the value of the branchcondition property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHCONDITION(String value) {
        this.branchcondition = value;
    }

    /**
     * Gets the value of the branchpattern property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHPATTERN() {
        return branchpattern;
    }

    /**
     * Sets the value of the branchpattern property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHPATTERN(String value) {
        this.branchpattern = value;
    }

    /**
     * Gets the value of the branchgoto property.
     * 
     */
    public long getBRANCHGOTO() {
        return branchgoto;
    }

    /**
     * Sets the value of the branchgoto property.
     * 
     */
    public void setBRANCHGOTO(long value) {
        this.branchgoto = value;
    }

    /**
     * Gets the value of the clearprevvalues property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLEARPREVVALUES() {
        return clearprevvalues;
    }

    /**
     * Sets the value of the clearprevvalues property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLEARPREVVALUES(String value) {
        this.clearprevvalues = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/BRANCHCONDITIONDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BRANCHCONDITIONDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="BRANCHCONDITIONDETAILS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BRANCHCONDITION"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BRANCHPATTERN"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BRANCHGOTO"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CLEARPREVVALUES" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BRANCHCONDITIONDETAILS_Type", propOrder = {
    "branchcondition",
    "branchpattern",
    "branchgoto",
    "clearprevvalues"
})
public class BRANCHCONDITIONDETAILS_Type {

    @XmlElement(name = "BRANCHCONDITION", required = true)
    protected String branchcondition;
    @XmlElement(name = "BRANCHPATTERN", required = true)
    protected String branchpattern;
    @XmlElement(name = "BRANCHGOTO")
    protected long branchgoto;
    @XmlElement(name = "CLEARPREVVALUES")
    protected String clearprevvalues;

    /**
     * Gets the value of the branchcondition property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHCONDITION() {
        return branchcondition;
    }

    /**
     * Sets the value of the branchcondition property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHCONDITION(String value) {
        this.branchcondition = value;
    }

    /**
     * Gets the value of the branchpattern property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBRANCHPATTERN() {
        return branchpattern;
    }

    /**
     * Sets the value of the branchpattern property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBRANCHPATTERN(String value) {
        this.branchpattern = value;
    }

    /**
     * Gets the value of the branchgoto property.
     * 
     */
    public long getBRANCHGOTO() {
        return branchgoto;
    }

    /**
     * Sets the value of the branchgoto property.
     * 
     */
    public void setBRANCHGOTO(long value) {
        this.branchgoto = value;
    }

    /**
     * Gets the value of the clearprevvalues property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCLEARPREVVALUES() {
        return clearprevvalues;
    }

    /**
     * Sets the value of the clearprevvalues property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCLEARPREVVALUES(String value) {
        this.clearprevvalues = value;
    }

}
